@@ -73,7 +73,7 @@ void Export_pyste_src_Image()
         .def(init< const Magick::Blob&, const Magick::Geometry&, const size_t >())
         .def(init< const Magick::Blob&, const Magick::Geometry&, const size_t, const std::string& >())
         .def(init< const Magick::Blob&, const Magick::Geometry&, const std::string& >())
-        .def(init< const size_t, const size_t, const std::string&, const MagickCore::StorageType, const void* >())
+        .def(init< const size_t, const size_t, const std::string&, const MagickCore::StorageType, const char* >())
         .def(init< const Magick::Image& >())
         .def(init< MagickCore::Image* >())
         .def("adaptiveThreshold", &Magick::Image::adaptiveThreshold, Magick_Image_adaptiveThreshold_overloads_2_3())
@@ -153,7 +153,6 @@ void Export_pyste_src_Image()
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const size_t) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const size_t, const std::string&) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const std::string&) )&Magick::Image::read)
-        .def("read", (void (Magick::Image::*)(const size_t, const size_t, const std::string&, const MagickCore::StorageType, const void*) )&Magick::Image::read)
         .def("reduceNoise", (void (Magick::Image::*)() )&Magick::Image::reduceNoise)
         .def("reduceNoise", (void (Magick::Image::*)(const double) )&Magick::Image::reduceNoise)
         .def("resize", &Magick::Image::resize)
@@ -186,7 +185,6 @@ void Export_pyste_src_Image()
         .def("write", (void (Magick::Image::*)(Magick::Blob*) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&, const size_t) )&Magick::Image::write)
-        .def("write", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const size_t, const size_t, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
         .def("zoom", &Magick::Image::zoom)
         .def("adjoin", (void (Magick::Image::*)(const bool) )&Magick::Image::adjoin)
         .def("adjoin", (bool (Magick::Image::*)() const)&Magick::Image::adjoin)
